==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/ButtonGroupSelectionChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ButtonGroupSelectionChangedEventArgsDescription } from "./ButtonGroupSelectionChangedEventArgsDescription";
/**
 * @hidden
 */
export let ButtonGroupSelectionChangedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class ButtonGroupSelectionChangedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (ButtonGroupSelectionChangedEventArgsDescriptionMetadata.a == null) {
                ButtonGroupSelectionChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ButtonGroupSelectionChangedEventArgsDescriptionMetadata.c(ButtonGroupSelectionChangedEventArgsDescriptionMetadata.a);
            }
            if (a.j(ButtonGroupSelectionChangedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.y(ButtonGroupSelectionChangedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
        }
        static d(a) {
            ButtonGroupSelectionChangedEventArgsDescriptionMetadata.b(a);
            a.aa("ButtonGroupSelectionChangedEventArgs", () => new ButtonGroupSelectionChangedEventArgsDescription());
            a.z("ButtonGroupSelectionChangedEventArgs", ButtonGroupSelectionChangedEventArgsDescriptionMetadata.a);
        }
    }
    ButtonGroupSelectionChangedEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(ButtonGroupSelectionChangedEventArgsDescriptionMetadata, 'ButtonGroupSelectionChangedEventArgsDescriptionMetadata');
    ButtonGroupSelectionChangedEventArgsDescriptionMetadata.a = null;
    return ButtonGroupSelectionChangedEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/ButtonGroupSelectionChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ButtonGroupSelectionChangedEventArgsDescription } from "./ButtonGroupSelectionChangedEventArgsDescription";
/**
 * @hidden
 */
export let ButtonGroupSelectionChangedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class ButtonGroupSelectionChangedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (ButtonGroupSelectionChangedEventArgsDescriptionMetadata.a == null) {
                ButtonGroupSelectionChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ButtonGroupSelectionChangedEventArgsDescriptionMetadata.c(ButtonGroupSelectionChangedEventArgsDescriptionMetadata.a);
            }
            if (a.k(ButtonGroupSelectionChangedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(ButtonGroupSelectionChangedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
        }
        static d(a) {
            ButtonGroupSelectionChangedEventArgsDescriptionMetadata.b(a);
            a.ac("ButtonGroupSelectionChangedEventArgs", () => new ButtonGroupSelectionChangedEventArgsDescription());
            a.ab("ButtonGroupSelectionChangedEventArgs", ButtonGroupSelectionChangedEventArgsDescriptionMetadata.a);
        }
    }
    ButtonGroupSelectionChangedEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(ButtonGroupSelectionChangedEventArgsDescriptionMetadata, 'ButtonGroupSelectionChangedEventArgsDescriptionMetadata');
    ButtonGroupSelectionChangedEventArgsDescriptionMetadata.a = null;
    return ButtonGroupSelectionChangedEventArgsDescriptionMetadata;
})();
